#
# steering, Programme/schedule management for AURA
#
# Copyright (C) 2011-2017, 2020, Ernesto Rico Schmidt
# Copyright (C) 2017-2019, Ingo Leindecker
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from datetime import datetime, date, time

import requests
from django.utils import timezone

from steering.settings import CBA_AJAX_URL, CBA_API_KEY, DEBUG


def parse_datetime(date_string: str) -> datetime:
    """
    parse a datetime string and return a timezone aware datetime object
    """
    try:
        parsed_datetime = datetime.strptime(date_string, "%Y-%m-%d %H:%M:%S")
    except ValueError:
        parsed_datetime = datetime.strptime(date_string, "%Y-%m-%d %H:%M:%S%z")

    return timezone.make_aware(parsed_datetime)


def parse_date(date_string: str) -> date:
    """
    parse a date string and return a date object
    """
    return datetime.strptime(date_string, "%Y-%m-%d").date()


def parse_time(date_string: str) -> time:
    """
    parse a time string and return a time object
    """
    return datetime.strptime(date_string, "%H:%M:%S").time()


def get_audio_url(cba_id):
    """
    Retrieve the direct URL to the mp3 in CBA
    In order to retrieve the URL, stations need
       - to be whitelisted by CBA
       - an API Key

    For these contact cba@fro.at
    """

    if cba_id is None or cba_id == '' or CBA_API_KEY == '':
        return None
    else:
        if DEBUG:
            url = 'https://cba.fro.at/wp-content/plugins/cba/ajax/cba-get-filename.php?post_id=' + str(cba_id) + '&c=Ml3fASkfwR8'
        else:
            url = CBA_AJAX_URL + '?action=cba_ajax_get_filename&post_id=' + str(cba_id) + '&api_key=' + CBA_API_KEY

        audio_url = requests.get(url).json()

    return audio_url
